..  GENERATED FILE, DO NOT EDIT DIRECTLY

    This file is automatically generated using https://codeberg.org/slidge/legacy-module-template/
    Its source is at:
    https://codeberg.org/slidge/legacy-module-template/src/branch/main/docs/source/user/registration.rst.jinja
    Open a pull request for this repository instead, to benefit the documentation of all slidge-based gateways.

Registration
============


.. warning::

  Discord is actively fighting alternative clients such as slidcord. To prevent being detected, you should ideally (a) activate additional security features to your legacy account, such as 2FA and (b) establish “normal” traffic on your account, from slidge’s IP.

  For (b), the most convenient way is to use a proxy (a SOCKS5 proxy is pretty easy to set up in case you have ssh access to your XMPP server) and configure your web browser to use this proxy whenever you access the web interface of your legacy network.


To start using a slidcord, you need to register your XMPP account with it.
The instance has a unique XMPP (aka JID) address, which is just a domain name (e.g., ``discord.example.org``, without any @ sign in it).

There are two ways to register, depending on which XMPP/Jabber client you are using:

- If your client supports adhoc commands (such as Movim, Gajim, or Cheogram),
  you can use the "Register" command with the slidcord instance's
  address.
- If your client does not support adhoc commands (such as Conversations), you
  can register by sending a text message that says "register" to the
  slidcord instance's address.
